@@ -151,15 +151,23 @@ flex_prms <- function(object, ...) {
 
 #' @rdname flex_prms
 #' @export
-flex_prms.numeric <- function(object, ..., conds, instr = NULL,
-                              messaging = NULL) {
+flex_prms.numeric <- function(
+  object,
+  ...,
+  conds,
+  instr = NULL,
+  messaging = NULL
+) {
   prms_model <- object
 
   # input checks
   if (length(prms_model) == 0) {
     stop("supplied prms_model (object) has length 0")
   }
-  check_if_named_numeric_vector(x = prms_model, var_name = "prms_model (object)")
+  check_if_named_numeric_vector(
+    x = prms_model,
+    var_name = "prms_model (object)"
+  )
   if (!is.character(conds) | length(conds) == 0) {
     stop("conds is not a character vector of length >= 1")
   }
@@ -171,12 +179,10 @@ flex_prms.numeric <- function(object, ..., conds, instr = NULL,
     stop("some condition name contain illegal non-alphanumeric characters")
   }
 
-
   # extract the parmaeter values and the parameter names
   prms_vals <- unname(prms_model)
   name_prms_model <- names(prms_model)
 
-
   # create the internal_list
   internal_list <- vector("list", length(name_prms_model))
   names(internal_list) <- name_prms_model
@@ -186,19 +192,18 @@ flex_prms.numeric <- function(object, ..., conds, instr = NULL,
     return(one_internal_entry)
   })
 
-
   # create the linearized internal_list
   linear_internal_list <- linearize_internal_list(internal_list)
 
-
   # create the matrix of all prms
-  prms_vals_matrix <- matrix(rep(prms_vals, length(conds)),
-    nrow = length(conds), byrow = TRUE
+  prms_vals_matrix <- matrix(
+    rep(prms_vals, length(conds)),
+    nrow = length(conds),
+    byrow = TRUE
   )
   rownames(prms_vals_matrix) <- conds
   colnames(prms_vals_matrix) <- name_prms_model
 
-
   # assemble everything
   flex_prms_obj <- list(
     internal_list = internal_list,
@@ -208,23 +213,20 @@ flex_prms.numeric <- function(object, ..., conds, instr = NULL,
 
   class(flex_prms_obj) <- "flex_prms"
 
-
   # run optional instructions
   flex_prms_obj <- modify_flex_prms(
-    object = flex_prms_obj, instr = instr,
+    object = flex_prms_obj,
+    instr = instr,
     messaging = messaging
   )
 
-
   # and pass back
   return(flex_prms_obj)
 }
 
 
-
 # FUNCTION FOR INJECTING A PARAMETER VECTOR -------------------------------
 
-
 #' Update the parameter matrix for vector inputs (internal docu)
 #'
 #' This function takes a numeric vector and maps the values to the parameter
@@ -251,8 +253,12 @@ x2prms_vals <- function(x, flex_prms_obj) {
   for (one_prm in colnames(prms_matrix)) {
     for (one_cond in rownames(prms_matrix)) {
       prm_pos <- linear_internal_list[[one_prm]][[one_cond]]
-      if (is.expression(prm_pos)) next
-      if (prm_pos == 0) next
+      if (is.expression(prm_pos)) {
+        next
+      }
+      if (prm_pos == 0) {
+        next
+      }
       prms_matrix[one_cond, one_prm] <- x[prm_pos]
     }
   }
@@ -413,7 +419,8 @@ modify_flex_prms.drift_dm <- function(object, instr, ..., eval_model = FALSE) {
   # replace old flex_prms_object
   object$flex_prms_obj <- modify_flex_prms(
     object$flex_prms_obj,
-    instr = instr, ...
+    instr = instr,
+    ...
   )
 
   # ensure that everything is up-to-date
@@ -434,8 +441,24 @@ modify_flex_prms.drift_dm <- function(object, instr, ..., eval_model = FALSE) {
 modify_flex_prms.flex_prms <- function(object, instr, ..., messaging = NULL) {
   flex_prms_obj <- object
 
-  if (is.null(messaging)) messaging <- TRUE
+  # input checks and default value handling
+  if (is.null(instr)) {
+    return(flex_prms_obj)
+  }
 
+  if (!is.character(instr)) {
+    stop("argument 'instr' must be character")
+  }
+
+  if (is.null(messaging)) {
+    messaging <- TRUE
+  }
+
+  if (!is.logical(messaging) | length(messaging) != 1) {
+    stop("messaging must be a single logical")
+  }
+
+  # messaging handling
   if (!messaging) {
     flex_prms_obj <- suppressMessages(
       modify_flex_prms(
@@ -446,25 +469,9 @@ modify_flex_prms.flex_prms <- function(object, instr, ..., messaging = NULL) {
     return(flex_prms_obj)
   }
 
-  # input checks
-  if (!inherits(flex_prms_obj, "flex_prms")) {
-    stop("flex_prms_obj is not of type flex_prms")
-  }
-
-  if (is.null(instr)) {
-    return(flex_prms_obj)
-  }
-
-  if (!is.character(instr)) {
-    stop("argument 'instr' must be character")
-  }
-
+  # paste instr
   instr <- paste(instr, collapse = "\n")
 
-  if (!is.logical(messaging) | length(messaging) != 1) {
-    stop("messaging must be single logical")
-  }
-
   # remove comments from instr
   instr <- gsub("#[^\n]*", "", instr)
 
@@ -537,7 +544,6 @@ modify_flex_prms.flex_prms <- function(object, instr, ..., messaging = NULL) {
 }
 
 
-
 # FUNCTIONS FOR CARRYING OUT THE INSTRUCTIONS -----------------------------
 
 #' Allow parameters to vary
@@ -558,7 +564,8 @@ flex_vary_prms <- function(flex_prms_obj, formula_instr) {
   new_list <- flex_prms_obj$internal_list
 
   prms_conds <- prms_conds_to_modify(
-    formula_instr = formula_instr, operation = "vary",
+    formula_instr = formula_instr,
+    operation = "vary",
     all_conds = rownames(flex_prms_obj$prms_matrix),
     all_prms = colnames(flex_prms_obj$prms_matrix)
   )
@@ -574,8 +581,11 @@ flex_vary_prms <- function(flex_prms_obj, formula_instr) {
       # check if the current value is an expression
       if (is.expression(cur_val)) {
         warning(
-          "Freeing parameter ", one_prm, " for condition ",
-          one_cond, ". Special depencies were overwritten."
+          "Freeing parameter ",
+          one_prm,
+          " for condition ",
+          one_cond,
+          ". Special depencies were overwritten."
         )
       }
     }
@@ -615,7 +625,8 @@ flex_restrain_prms <- function(flex_prms_obj, formula_instr) {
   new_prms_matrix <- flex_prms_obj$prms_matrix
 
   prms_conds <- prms_conds_to_modify(
-    formula_instr = formula_instr, operation = "restrain",
+    formula_instr = formula_instr,
+    operation = "restrain",
     all_conds = rownames(new_prms_matrix),
     all_prms = colnames(new_prms_matrix)
   )
@@ -624,8 +635,11 @@ flex_restrain_prms <- function(flex_prms_obj, formula_instr) {
 
   if (length(conds_to_adress) == 1) {
     warning(
-      "restraining parameter(s) ", paste(prms_to_adress, collapse = ", "),
-      " only for one condition (", conds_to_adress, ") makes rarely",
+      "restraining parameter(s) ",
+      paste(prms_to_adress, collapse = ", "),
+      " only for one condition (",
+      conds_to_adress,
+      ") makes rarely",
       " sense; double-check if your instructions led to the intended",
       " result"
     )
@@ -638,14 +652,16 @@ flex_restrain_prms <- function(flex_prms_obj, formula_instr) {
       # check if the current value is an expression
       if (is.expression(cur_val)) {
         warning(
-          "Restraining parameter ", one_prm, " for condition ",
-          one_cond, ". Special depencies were overwritten."
+          "Restraining parameter ",
+          one_prm,
+          " for condition ",
+          one_cond,
+          ". Special depencies were overwritten."
         )
       }
     }
   }
 
-
   # now iterate through all parameters and modify the internal list
   for (one_prm in prms_to_adress) {
     max_curr_number <- max_number_one_internal_entry(new_list[[one_prm]])
@@ -669,7 +685,6 @@ flex_restrain_prms <- function(flex_prms_obj, formula_instr) {
 }
 
 
-
 #' Set a specific value to the parameter matrix (internal docu)
 #'
 #' This function takes a flex_prms_obj and sets certain values to the parameter
@@ -715,15 +730,14 @@ flex_specific_value <- function(flex_prms_obj, formula_instr) {
 
   # convert the character input to numeric
   vals_to_set <- sapply(vals_to_set, function(one_val) {
-    tryCatch(as.numeric(one_val),
-      warning = function(w) {
-        stop(
-          "Couldn't convert input right of => to ",
-          "numbers. This is the expression for which ",
-          "conversions crashed; ", formula_instr
-        )
-      }
-    )
+    tryCatch(as.numeric(one_val), warning = function(w) {
+      stop(
+        "Couldn't convert input right of => to ",
+        "numbers. This is the expression for which ",
+        "conversions crashed; ",
+        formula_instr
+      )
+    })
   })
 
   # find the special links between parameters and maybe usher a message
@@ -736,21 +750,30 @@ flex_specific_value <- function(flex_prms_obj, formula_instr) {
       # check if the current value is an expression
       if (is.expression(cur_val)) {
         warning(
-          "Setting a specific value for parameter ", one_prm,
-          " in condition ", one_cond, ", which has a special dependency",
+          "Setting a specific value for parameter ",
+          one_prm,
+          " in condition ",
+          one_cond,
+          ", which has a special dependency",
           " on other parameters. This will not have an effect."
         )
       } else {
         # check if conds_to_adress match with the number of conditions for
         # which a specific parameter is restrained
         ident_conds <- names(all_vals)[which(cur_val == all_vals)]
-        if (cur_val == 0) next()
+        if (cur_val == 0) {
+          next()
+        }
         if (length(ident_conds) >= 2 & !all(ident_conds %in% conds_to_adress)) {
           message(
-            "Setting a specific value for parameter ", one_prm,
-            " in condition ", one_cond, ". This parameter is assumed to",
+            "Setting a specific value for parameter ",
+            one_prm,
+            " in condition ",
+            one_cond,
+            ". This parameter is assumed to",
             " be identical across conditions ",
-            paste(ident_conds, collapse = ", "), ".",
+            paste(ident_conds, collapse = ", "),
+            ".",
             " Not problematic per se, just be aware of this"
           )
         }
@@ -769,7 +792,6 @@ flex_specific_value <- function(flex_prms_obj, formula_instr) {
 }
 
 
-
 #' Exclude parameters from being modified (i.e., fix it; internal docu)
 #'
 #' This function modifies the (linear) internal list and sets the desired
@@ -788,14 +810,14 @@ flex_fix_prms <- function(flex_prms_obj, formula_instr) {
   new_list <- flex_prms_obj$internal_list
 
   prms_conds <- prms_conds_to_modify(
-    formula_instr = formula_instr, operation = "fix",
+    formula_instr = formula_instr,
+    operation = "fix",
     all_conds = rownames(flex_prms_obj$prms_matrix),
     all_prms = colnames(flex_prms_obj$prms_matrix)
   )
   prms_to_adress <- prms_conds$prms_to_adress
   conds_to_adress <- prms_conds$conds_to_adress
 
-
   # find the special links between parameters and maybe usher a warning
   for (one_prm in prms_to_adress) {
     one_entry <- new_list[[one_prm]]
@@ -805,14 +827,16 @@ flex_fix_prms <- function(flex_prms_obj, formula_instr) {
       # check if the current value is an expression
       if (is.expression(cur_val)) {
         warning(
-          "Setting parameter ", one_prm, " as fixed for condition ",
-          one_cond, ". Special depencies were overwritten."
+          "Setting parameter ",
+          one_prm,
+          " as fixed for condition ",
+          one_cond,
+          ". Special depencies were overwritten."
         )
       }
     }
   }
 
-
   # now iterate through all parameters and modify the internal list
   for (one_prm in prms_to_adress) {
     new_list[[one_prm]][conds_to_adress] <- 0L
@@ -828,8 +852,6 @@ flex_fix_prms <- function(flex_prms_obj, formula_instr) {
 }
 
 
-
-
 #' Set special dependencies (internal docu)
 #'
 #' Sets special dependencies so that parameters depend on other parameters.
@@ -858,8 +880,6 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
   prms_to_adress <- prms_conds$prms_to_adress
   conds_to_adress <- prms_conds$conds_to_adress
 
-
-
   # usher a message if setting parameter with special dependency on another
   # parameter that has a special instruction
   # also check if prm~cond combo is as on the left hand side and if legit names
@@ -867,10 +887,14 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
   depends_on <- trimws(strsplit(formula_instr, "==")[[1]][2])
 
   # find the parameters and conditions on which the intended dependency builds
-  prms_regex <- gregexpr("(?<=\\()[\\s]*[\\w]+[\\s]*(?=~)", depends_on,
+  prms_regex <- gregexpr(
+    "(?<=\\()[\\s]*[\\w]+[\\s]*(?=~)",
+    depends_on,
     perl = TRUE
   )
-  conds_regex <- gregexpr("(?<=~)[\\s]*[\\w]+[\\s]*(?=\\))", depends_on,
+  conds_regex <- gregexpr(
+    "(?<=~)[\\s]*[\\w]+[\\s]*(?=\\))",
+    depends_on,
     perl = TRUE
   )
   prms_depend <- unlist(regmatches(depends_on, prms_regex))
@@ -882,13 +906,15 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
   if (!any(prms_depend %in% model_prms)) {
     stop(
       "prms on the right hand side don't match with the model parameters. ",
-      "Found in ", formula_instr
+      "Found in ",
+      formula_instr
     )
   }
   if (!any(conds_depend %in% model_conds)) {
     stop(
       "conds on the right hand side don't match with the model parameters. ",
-      "Found in ", formula_instr
+      "Found in ",
+      formula_instr
     )
   }
 
@@ -906,7 +932,6 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
     }
   }
 
-
   # now iterate through all parameters and modify the internal list
   expr <- gsub("(\\w+)\\s*~\\s*(\\w+)", "prms_matrix['\\2', '\\1']", depends_on)
   for (i in seq_along(prms_to_adress)) {
@@ -917,7 +942,6 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
     new_list[[one_prm]] <- sort_one_internal_entry(new_list[[one_prm]])
   }
 
-
   # set and re-linearize and check to ensure everything is up-to-date
   flex_prms_obj$internal_list <- new_list
   new_linear_list <- linearize_internal_list(internal_list = new_list)
@@ -936,7 +960,6 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
     )
   }
 
-
   # update the special dependencies
   flex_prms_obj <- update_special_values(flex_prms_obj)
 
@@ -944,7 +967,6 @@ flex_special_dependency <- function(flex_prms_obj, formula_instr) {
 }
 
 
-
 #' Specify custom parameters
 #'
 #' This function takes a flex_prms_obj and adds or builds the entry `cust_prms`
@@ -983,7 +1005,9 @@ flex_cust_prm <- function(flex_prms_obj, formula_instr) {
 
   if (is.na(cust_prm_name)) {
     stop(
-      "left side of ", paste("'", formula_instr, "'", sep = ""), "is not ",
+      "left side of ",
+      paste("'", formula_instr, "'", sep = ""),
+      "is not ",
       "a valid name"
     )
   }
@@ -995,7 +1019,8 @@ flex_cust_prm <- function(flex_prms_obj, formula_instr) {
 
   if (is.na(math_exp)) {
     stop(
-      "right side of ", paste("'", formula_instr, "'", sep = ""),
+      "right side of ",
+      paste("'", formula_instr, "'", sep = ""),
       " is empty"
     )
   }
@@ -1009,12 +1034,12 @@ flex_cust_prm <- function(flex_prms_obj, formula_instr) {
   depends_on <- unlist(regmatches(math_exp, prms_regex))
   if (!all(depends_on %in% colnames(flex_prms_obj$prms_matrix))) {
     stop(
-      "right side of ", paste("'", formula_instr, "'", sep = ""),
+      "right side of ",
+      paste("'", formula_instr, "'", sep = ""),
       " specifies parameters that are not part of the model"
     )
   }
 
-
   # make an expression and pack it up
   cust_expr <- list(parse(text = string_exp))
   names(cust_expr) <- cust_prm_name
@@ -1032,7 +1057,9 @@ flex_cust_prm <- function(flex_prms_obj, formula_instr) {
   } else {
     if (cust_prm_name %in% names(cust_prms$expressions)) {
       message(
-        "Custom parameter ", cust_prm_name, " already exists.",
+        "Custom parameter ",
+        cust_prm_name,
+        " already exists.",
         " Replacing old one"
       )
     }
@@ -1040,12 +1067,10 @@ flex_cust_prm <- function(flex_prms_obj, formula_instr) {
     cust_prms$expressions[[cust_prm_name]] <- NULL
     cust_prms$values[[cust_prm_name]] <- NULL
 
-
     cust_prms$expressions <- c(cust_prms$expressions, cust_expr)
     cust_prms$values <- c(cust_prms$values, place_holder)
   }
 
-
   # update the values
   flex_prms_obj$cust_prms <- cust_prms
   flex_prms_obj <- update_special_values(flex_prms_obj)
@@ -1094,7 +1119,6 @@ linearize_internal_list <- function(internal_list) {
     start:end
   })
 
-
   # now do the remapping. For this end, iterate through the list and choose
   # the corresponding new value for those entries that are digits > 1
   # for each parameter (index) do...
@@ -1114,8 +1138,6 @@ linearize_internal_list <- function(internal_list) {
 }
 
 
-
-
 #' Count the number of digits > 0
 #'
 #' This function takes one entry of the internal_list (i.e., all conditions for
@@ -1127,8 +1149,11 @@ linearize_internal_list <- function(internal_list) {
 #'
 #' @keywords internal
 count_unique_prms_one_internal_entry <- function(one_internal_entry) {
-  values <- one_internal_entry[sapply(one_internal_entry, \(x) !is.expression(x))]
-  if (length(values) == 0) { # happens if there are only expressions
+  values <- one_internal_entry[sapply(one_internal_entry, \(x) {
+    !is.expression(x)
+  })]
+  if (length(values) == 0) {
+    # happens if there are only expressions
     return(0)
   }
   values <- unique(unlist(values))
@@ -1146,8 +1171,7 @@ count_unique_prms_one_internal_entry <- function(one_internal_entry) {
 #' @keywords internal
 is_empty <- function(x) {
   stopifnot(length(x) <= 1)
-
-  (length(x) == 0) | (all(x == ""))
+  (length(x) == 0) || (all(!nzchar(x)))
 }
 
 
@@ -1171,8 +1195,12 @@ is_empty <- function(x) {
 #' vectors.
 #'
 #' @keywords internal
-prms_conds_to_modify <- function(formula_instr, operation,
-                                 all_conds, all_prms) {
+prms_conds_to_modify <- function(
+  formula_instr,
+  operation,
+  all_conds,
+  all_prms
+) {
   # input checks
   stopifnot(is.character(formula_instr) & length(formula_instr) == 1)
   operation <- match.arg(
@@ -1182,7 +1210,6 @@ prms_conds_to_modify <- function(formula_instr, operation,
   stopifnot(is.character(all_conds) & length(all_conds) >= 1)
   stopifnot(is.character(all_prms) & length(all_prms) >= 1)
 
-
   # checks about the type of instruction should have happend prior to the call
   if (operation == "vary") {
     split_vector <- strsplit(formula_instr, "~")[[1]]
@@ -1204,43 +1231,46 @@ prms_conds_to_modify <- function(formula_instr, operation,
     split_vector <- strsplit(formula_instr, "==")[[1]]
   }
 
-
   if (length(split_vector) > 2 & operation == "vary") {
     stop(
       "Only a single '~' allowed when setting parameters to vary; ",
-      "found in: ", formula_instr
+      "found in: ",
+      formula_instr
     )
   }
 
   if (length(split_vector) > 2 & operation == "set") {
     stop(
-      "Only a single '~' allowed when setting specific parameter values; ",
-      "found in: ", formula_instr
+      "Only a single '=>' allowed when setting specific parameter values; ",
+      "found in: ",
+      formula_instr
     )
   }
 
   if (length(split_vector) > 2 & operation == "restrain") {
     stop(
       "Only a single '~!' allowed when restraining parameters; ",
-      "found in: ", formula_instr
+      "found in: ",
+      formula_instr
     )
   }
 
   if (length(split_vector) > 2 & operation == "fix") {
     stop(
       "Only a single '<!>' allowed when setting parameters as fixed; ",
-      "found in: ", formula_instr
+      "found in: ",
+      formula_instr
     )
   }
 
   if (length(split_vector) > 2 & operation == "dependency") {
     stop(
       "Only a single '==' allowed when setting special dependencies; ",
-      "found in: ", formula_instr
+      "found in: ",
+      formula_instr
     )
   }
 
-
   # left hand side of == or => must be broken down further
   if (operation == "set" | operation == "dependency") {
     split_vector <- strsplit(split_vector[1], split = "~")[[1]]
@@ -1251,7 +1281,6 @@ prms_conds_to_modify <- function(formula_instr, operation,
     stop("there were more than one '~' to indicate conditions and parameters")
   }
 
-
   # happens for formula_instr like "~" (i.e., when there is nothing at the
   # start of the string; in this case add "" and proceed
   if (length(split_vector) == 1) {
@@ -1270,7 +1299,6 @@ prms_conds_to_modify <- function(formula_instr, operation,
   prms_to_adress <- trimws(prms_to_adress)
   conds_to_adress <- trimws(conds_to_adress)
 
-
   # adress all prms if corresponding vector was ""
   if (all(sapply(prms_to_adress, is_empty))) {
     prms_to_adress <- all_prms
@@ -1285,13 +1313,15 @@ prms_conds_to_modify <- function(formula_instr, operation,
   if (!all(conds_to_adress %in% all_conds)) {
     stop(
       "some conditions in the instructions don't match with the conditions",
-      " of the model. Found in: ", formula_instr
+      " of the model. Found in: ",
+      formula_instr
     )
   }
   if (!all(prms_to_adress %in% all_prms)) {
     stop(
       "some parameters in the instructions don't match with the parameters",
-      " of the model. Found in: ", formula_instr
+      " of the model. Found in: ",
+      formula_instr
     )
   }
 
@@ -1302,7 +1332,6 @@ prms_conds_to_modify <- function(formula_instr, operation,
 }
 
 
-
 #' Get the maximum number from an internal entry or flex_prms_obj
 #' (internal docu)
 #'
@@ -1405,18 +1434,18 @@ update_special_values <- function(flex_prms_obj) {
 
   linear_internal_list <- flex_prms_obj$linear_internal_list
 
-
   # update the special dependencies
   # iterate again to update all special dependencies
   for (one_prm in prm_names) {
     for (one_cond in cond_names) {
       cur_val <- linear_internal_list[[one_prm]][[one_cond]]
-      if (!is.expression(cur_val)) next
+      if (!is.expression(cur_val)) {
+        next
+      }
       prms_matrix[one_cond, one_prm] <- eval(cur_val) # requires prms_matrix
     }
   }
 
-
   # update the custom parameters (if they exist)
   cust_prms <- flex_prms_obj$cust_prms
   if (!is.null(cust_prms)) {
@@ -1433,7 +1462,6 @@ update_special_values <- function(flex_prms_obj) {
 }
 
 
-
 #' checks if a flex_prms_object is parameterized in a reasonable way
 #'
 #'
@@ -1459,7 +1487,6 @@ validate_flex_prms <- function(flex_prms_obj) {
   prm_names <- colnames(flex_prms_obj$prms_matrix)
   cond_names <- rownames(flex_prms_obj$prms_matrix)
 
-
   # check the matrix and names
   if (!is.character(cond_names) | length(cond_names) == 0) {
     stop("condition names are not a character vector of length >= 1")
@@ -1493,8 +1520,6 @@ validate_flex_prms <- function(flex_prms_obj) {
     stop("there are duplicate parameters names")
   }
 
-
-
   # involves check that prms_matrix is a numeric matrix with unique parameter
   # entries
   for (one_cond in cond_names) {
@@ -1508,7 +1533,6 @@ validate_flex_prms <- function(flex_prms_obj) {
     )
   }
 
-
   # check the internal list
   if (!is.list(internal_list) | !is.list(linear_internal_list)) {
     stop("internal_list or linear_internal_list is not of type list")
@@ -1528,8 +1552,10 @@ validate_flex_prms <- function(flex_prms_obj) {
 
   # check the custom parameters
   if (!is.null(cust_prms)) {
-    if (length(cust_prms) != 2 ||
-      any(names(cust_prms) != c("expressions", "values"))) {
+    if (
+      length(cust_prms) != 2 ||
+        any(names(cust_prms) != c("expressions", "values"))
+    ) {
       stop("cust_prms not named with 'expressions' and 'values'")
     }
     check <- sapply(cust_prms$expressions, \(x) !is.expression(x))
@@ -1553,9 +1579,6 @@ validate_flex_prms <- function(flex_prms_obj) {
 }
 
 
-
-
-
 #' checks if all entries of internal_list are an expression or integer.
 #' Throws an error if not (internal docu)
 #'
@@ -1574,7 +1597,8 @@ check_internal_list <- function(internal_list, prm_names, cond_names) {
   if (!isTRUE(all.equal(names(internal_list), prm_names))) {
     stop(
       "an internal_list in flex_prms_object can not be adressed via",
-      " the names ", paste(prm_names, collapse = ", ")
+      " the names ",
+      paste(prm_names, collapse = ", ")
     )
   }
 
@@ -1583,7 +1607,8 @@ check_internal_list <- function(internal_list, prm_names, cond_names) {
     if (!isTRUE(all.equal(names(one_entry), cond_names))) {
       stop(
         "an entry of an internal_list in flex_prms_object can not be ",
-        "adressed via the names ", paste(cond_names, collapse = ", ")
+        "adressed via the names ",
+        paste(cond_names, collapse = ", ")
       )
     }
 
@@ -1611,8 +1636,6 @@ check_internal_list <- function(internal_list, prm_names, cond_names) {
 }
 
 
-
-
 #' Turn an internal list to a matrix
 #'
 #' this function wrangles the internal list to character matrix
@@ -1628,13 +1651,17 @@ internal_list_to_matrix <- function(internal_list) {
   prms <- names(internal_list)
   conds <- names(internal_list[[1]])
 
-  values <- mapply(function(cond, prm) {
-    value <- internal_list[[prm]][[cond]]
-    if (is.numeric(value)) {
-      return(value)
-    }
-    return("d")
-  }, conds, rep(prms, each = length(conds)))
+  values <- mapply(
+    function(cond, prm) {
+      value <- internal_list[[prm]][[cond]]
+      if (is.numeric(value)) {
+        return(value)
+      }
+      return("d")
+    },
+    conds,
+    rep(prms, each = length(conds))
+  )
   matrix <- matrix(values, nrow = length(conds))
   rownames(matrix) <- conds
   colnames(matrix) <- prms
@@ -1643,11 +1670,8 @@ internal_list_to_matrix <- function(internal_list) {
 }
 
 
-
-
 # METHODS TO EXTRACT FLEX_PRMS --------------------------------------------
 
-
 #' @rdname flex_prms
 #' @export
 flex_prms.flex_prms <- function(object, ...) {
