@@ -1,5 +1,6 @@
 test_that("flex_prms -> creation works as expected", {
-  a_flex_prms_obj <- flex_prms(c(a = 2, b = 3, c = 5),
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
     conds = c("foo", "bar", "uff", "lorem")
   )
 
@@ -23,7 +24,6 @@ test_that("flex_prms -> creation works as expected", {
       all.equal(dim(a_flex_prms_obj$prms_matrix), c(4, 3))
   )
 
-
   # flex_prms methods
   expect_equal(flex_prms(a_flex_prms_obj), a_flex_prms_obj)
   a_model <- list(flex_prms_obj = a_flex_prms_obj)
@@ -38,7 +38,6 @@ test_that("flex_prms -> input checks", {
     "has length 0"
   )
 
-
   expect_error(
     flex_prms(c(ao.e = 3), conds = c("foo", "bar")),
     "illegal non-alphanumeric characters"
@@ -62,7 +61,8 @@ test_that("flex_prms -> input checks", {
 
 
 test_that("x2prms_vals works as expected", {
-  a_flex_prms_obj <- flex_prms(c(a = 2, b = 3, c = 5),
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
     conds = c("foo", "bar", "uff", "lorem"),
     instr = "a ~ foo + bar
                               b ~ bar == (a ~ foo) + 3
@@ -71,11 +71,23 @@ test_that("x2prms_vals works as expected", {
 
   a_flex_prms_obj <- x2prms_vals(c(5, 8, 9, 10, 11), a_flex_prms_obj)
 
-  exp_matrix <- matrix(c(
-    5, 8, 9, 9,
-    10, 8, 10, 10,
-    11, 11, 11, 11
-  ), nrow = 4)
+  exp_matrix <- matrix(
+    c(
+      5,
+      8,
+      9,
+      9,
+      10,
+      8,
+      10,
+      10,
+      11,
+      11,
+      11,
+      11
+    ),
+    nrow = 4
+  )
   colnames(exp_matrix) <- c("a", "b", "c")
   rownames(exp_matrix) <- c("foo", "bar", "uff", "lorem")
 
@@ -86,7 +98,8 @@ test_that("x2prms_vals works as expected", {
 
 
 test_that("modify_flex_prms -> all instructions work as expected", {
-  a_flex_prms_obj <- flex_prms(c(a = 2, b = 3, c = 5),
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
     conds = c("foo", "bar", "uff")
   )
 
@@ -166,11 +179,11 @@ test_that("modify_flex_prms -> all instructions work as expected", {
     c(foo = 0, bar = 0, uff = 0)
   )
 
-
   # special dependency
   a_flex_prms_obj <- modify_flex_prms(
     object = a_flex_prms_obj,
-    instr = "b + a ~ foo + bar == -(c ~ bar) * 2 / 3", messaging = F
+    instr = "b + a ~ foo + bar == -(c ~ bar) * 2 / 3",
+    messaging = F
   )
   expect_true(is.expression(a_flex_prms_obj$linear_internal_list$a$foo))
   expect_true(is.expression(a_flex_prms_obj$linear_internal_list$a$bar))
@@ -182,7 +195,6 @@ test_that("modify_flex_prms -> all instructions work as expected", {
 
   expect_snapshot(a_flex_prms_obj)
 
-
   # custom parameter
   a_flex_prms_obj <- modify_flex_prms(
     object = a_flex_prms_obj,
@@ -198,11 +210,24 @@ test_that("modify_flex_prms -> all instructions work as expected", {
     a_flex_prms_obj$cust_prms$values$e,
     c(foo = -0.32, bar = -0.26, uff = 0.49)
   )
+
+  # address all parameters
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
+    conds = c("foo", "bar"),
+    instr = "<!> bar"
+  )
+
+  expect_equal(a_flex_prms_obj$linear_internal_list$a, list(foo = 1, bar = 0))
+
+  expect_equal(a_flex_prms_obj$linear_internal_list$b, list(foo = 2, bar = 0))
+  expect_equal(a_flex_prms_obj$linear_internal_list$c, list(foo = 3, bar = 0))
 })
 
 
 test_that("validate_flex_prms -> errs as expected", {
-  a_flex_prms_obj <- flex_prms(c(a = 2, b = 3, c = 5),
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
     conds = c("foo", "bar", "uff"),
     instr = "a ~ foo == -(b ~ uff)
                                        d := c + b"
@@ -252,7 +277,6 @@ test_that("validate_flex_prms -> errs as expected", {
     "no name"
   )
 
-
   temp <- a_flex_prms_obj
   temp$prms_matrix <- matrix(NA, nrow = 3, ncol = 0)
   expect_error(
@@ -274,8 +298,6 @@ test_that("validate_flex_prms -> errs as expected", {
     "duplicate conditions"
   )
 
-
-
   # parameter name checks
   temp <- a_flex_prms_obj
   colnames(temp$prms_matrix) <- NULL
@@ -291,7 +313,6 @@ test_that("validate_flex_prms -> errs as expected", {
     "no name"
   )
 
-
   temp <- a_flex_prms_obj
   temp$prms_matrix <- matrix(NA, nrow = 0, ncol = 3)
   expect_error(
@@ -318,12 +339,10 @@ test_that("validate_flex_prms -> errs as expected", {
   temp$prms_matrix[1, 1] <- as.character(temp$prms_matrix[1, 1])
   expect_error(validate_flex_prms(temp), "numeric")
 
-
   temp <- a_flex_prms_obj
   temp$prms_matrix[1, 1] <- NA
   expect_error(validate_flex_prms(temp), "NAs")
 
-
   # custom parameter checks
   temp <- a_flex_prms_obj
   temp$cust_prms$foo <- "foo"
@@ -339,7 +358,6 @@ test_that("validate_flex_prms -> errs as expected", {
     "not named with 'expressions' and 'values'"
   )
 
-
   temp <- a_flex_prms_obj
   temp$cust_prms$expressions <- "foo"
   expect_error(
@@ -364,7 +382,8 @@ test_that("validate_flex_prms -> errs as expected", {
 
 
 test_that("messages and warnings", {
-  a_flex_prms_obj <- flex_prms(c(a = 2, b = 3, c = 5),
+  a_flex_prms_obj <- flex_prms(
+    c(a = 2, b = 3, c = 5),
     conds = c("foo", "bar", "uff")
   )
 
@@ -373,17 +392,26 @@ test_that("messages and warnings", {
     "only for one condition"
   )
 
-
   expect_error(
-    modify_flex_prms(a_flex_prms_obj, "a ~
-                     a ~ foo + bar => 0.3 + 0.4 + 0.5"),
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~
+                     a ~ foo + bar => 0.3 + 0.4 + 0.5"
+    ),
     "don't match"
   )
 
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, "a ~ foo =>=> 0.4"),
+    "Only a single"
+  )
 
   expect_error(
-    modify_flex_prms(a_flex_prms_obj, "a ~
-                     a ~ foo + bar => 0..5"),
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~
+                     a ~ foo + bar => 0..5"
+    ),
     "Couldn't convert input"
   )
 
@@ -392,34 +420,50 @@ test_that("messages and warnings", {
     "assumed to be identical"
   )
 
-
-  expect_no_message(modify_flex_prms(a_flex_prms_obj,
+  expect_no_message(modify_flex_prms(
+    a_flex_prms_obj,
     "a ~ bar => 0.5",
     messaging = F
   ))
 
   expect_warning(
-    modify_flex_prms(a_flex_prms_obj, "a ~ bar == -(a ~ foo)
-                                       a ~ bar => 0.3"),
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~ bar == -(a ~ foo)
+                                       a ~ bar => 0.3"
+    ),
     "which has a special dependency"
   )
 
   expect_warning(
-    modify_flex_prms(a_flex_prms_obj, "a ~ bar == -(a ~ foo)
-                                       a ~! bar + foo"),
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~ bar == -(a ~ foo)
+                                       a ~! bar + foo"
+    ),
+    "overwritten"
+  )
+
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, "a ~!~! bar + foo"),
+    "Only a single"
+  )
+
+  expect_warning(
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~ bar == -(a ~ foo)
+                                       a ~"
+    ),
     "overwritten"
   )
 
   expect_warning(
-    modify_flex_prms(a_flex_prms_obj, "a ~ bar == -(a ~ foo)
-                                       a ~"),
-    "overwritten"
-  )
-
-
-  expect_warning(
-    modify_flex_prms(a_flex_prms_obj, "a ~ bar == -(a ~ foo)
-                                       a ~"),
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "a ~ bar == -(a ~ foo)
+                                       a ~"
+    ),
     "overwritten"
   )
 
@@ -438,25 +482,67 @@ test_that("messages and warnings", {
     "Recursive"
   )
 
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, "a ~~ bar == -(a ~ bar)"),
+    "there were more than one '~"
+  )
 
   expect_error(
     modify_flex_prms(a_flex_prms_obj, "e?e := a"),
     "not a valid name"
   )
 
-
   expect_error(
     modify_flex_prms(a_flex_prms_obj, "e := "),
     "empty"
   )
+
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, "e := a + d "),
+    "parameters that are not part of the model"
+  )
+
+  expect_message(
+    modify_flex_prms(
+      a_flex_prms_obj,
+      "e := a + c
+                                       e := a + b"
+    ),
+    "parameter e already exists. Replacing old one"
+  )
+
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, instr = 5),
+    "'instr' must be character"
+  )
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, instr = "a ~ ", messaging = "foo"),
+    "messaging must be a single logical"
+  )
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, instr = "a !! "),
+    "couldn't interprete instruction: a !!"
+  )
+
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, instr = "a <!> foo <!> to"),
+    "Only a single"
+  )
+
+  expect_error(
+    modify_flex_prms(a_flex_prms_obj, instr = "a ~ foo == == b ~ bar"),
+    "Only a single"
+  )
 })
 
 
 test_that("modify_flex_prms -> drift_dm", {
-  a_model <- readRDS(test_path("fixtures", "dmc.rds"))
-
-  a_model <- modify_flex_prms(a_model, instr = "muc ~
-                             alpha ~ => 5")
+  a_model <- dmc_dummy
+  a_model <- modify_flex_prms(
+    a_model,
+    instr = "muc ~
+                             alpha ~ => 5"
+  )
 
   expect_equal(
     a_model$flex_prms_obj$prms_matrix[, "alpha"],
